@@ -1,9 +1,9 @@
 package WWW::PAUSE::Simple;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-09-21'; # DATE
+our $DATE = '2021-05-23'; # DATE
 our $DIST = 'WWW-PAUSE-Simple'; # DIST
-our $VERSION = '0.449'; # VERSION
+our $VERSION = '0.450'; # VERSION
 
 use 5.010001;
 use strict;
@@ -957,7 +957,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.449 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2020-09-21.
+This document describes version 0.450 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2021-05-23.
 
 =head1 SYNOPSIS
 
@@ -973,7 +973,7 @@ There is also a CLI script L<pause> distributed separately in L<App::pause>.
 
 Usage:
 
- delete_files(%args) -> [status, msg, payload, meta]
+ delete_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Delete files.
 
@@ -1034,11 +1034,11 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1049,7 +1049,7 @@ Return value:  (any)
 
 Usage:
 
- delete_old_releases(%args) -> [status, msg, payload, meta]
+ delete_old_releases(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Delete older versions of distributions.
 
@@ -1129,11 +1129,11 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1144,7 +1144,7 @@ Return value:  (any)
 
 Usage:
 
- list_dists(%args) -> [status, msg, payload, meta]
+ list_dists(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List distributions.
 
@@ -1204,11 +1204,11 @@ not yet supported.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1219,7 +1219,7 @@ Return value:  (any)
 
 Usage:
 
- list_files(%args) -> [status, msg, payload, meta]
+ list_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List files.
 
@@ -1275,11 +1275,11 @@ not yet supported.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1290,7 +1290,7 @@ Return value:  (any)
 
 Usage:
 
- list_modules(%args) -> [status, msg, payload, meta]
+ list_modules(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List modules (permissions).
 
@@ -1338,11 +1338,11 @@ not yet supported.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1353,7 +1353,7 @@ Return value:  (any)
 
 Usage:
 
- reindex_files(%args) -> [status, msg, payload, meta]
+ reindex_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Force reindexing.
 
@@ -1406,11 +1406,11 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1421,7 +1421,7 @@ Return value:  (any)
 
 Usage:
 
- undelete_files(%args) -> [status, msg, payload, meta]
+ undelete_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Undelete files.
 
@@ -1478,11 +1478,11 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1493,7 +1493,7 @@ Return value:  (any)
 
 Usage:
 
- upload_files(%args) -> [status, msg, payload, meta]
+ upload_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Upload file(s).
 
@@ -1559,11 +1559,11 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -1580,7 +1580,7 @@ Source repository is at L<https://github.com/perlancar/perl-WWW-PAUSE-Simple>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WWW-PAUSE-Simple>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WWW-PAUSE-Simple/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -1604,7 +1604,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
